@@ -1,4 +1,4 @@
-/*	$Id: icb.c,v 1.14 2004/02/27 01:17:09 dhartmei Exp $ */
+/*	$Id: icb.c,v 1.3 2015/08/21 19:01:12 dhartmei Exp $ */
 
 /*
  * Copyright (c) 2003-2004 Daniel Hartmeier
@@ -30,7 +30,7 @@
  *
  */
 
-static const char rcsid[] = "$Id: icb.c,v 1.14 2004/02/27 01:17:09 dhartmei Exp $";
+static const char rcsid[] = "$Id: icb.c,v 1.3 2015/08/21 19:01:12 dhartmei Exp $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -41,7 +41,7 @@ static const char rcsid[] = "$Id: icb.c,v 1.14 2004/02/27 01:17:09 dhartmei Exp
 extern int	 sync_write(int, const char *, int);
 
 static unsigned char	 icb_args(const char *, unsigned char, char [255][255]);
-static void		 icb_cmd(const char *, unsigned char, int);
+static void		 icb_cmd(const char *, unsigned char, int, int);
 static void		 icb_ico(int, const char *);
 static void		 icb_iwl(int, const char *, const char *, long,
 			    long, const char *, const char *);
@@ -60,6 +60,7 @@ static char icurgroup[256];
 static char igroup[256];
 static char inick[256];
 static char ihostmask[256];
+static unsigned off;
 
 /*
  * A single ICB packet consists of a length byte, a command byte and
@@ -124,10 +125,24 @@ scan(const char **s, char *d, size_t siz, const char *skip, const char *term)
 }
 
 void
-icb_recv(const char *buf, unsigned len, int fd)
+icb_init(void)
+{
+	memset(icb_protolevel, 0, sizeof(icb_protolevel));
+	memset(icb_hostid, 0, sizeof(icb_hostid));
+	memset(icb_serverid, 0, sizeof(icb_serverid));
+	memset(icb_moderator, 0, sizeof(icb_moderator));
+	imode = imode_none;
+	memset(icurgroup, 0, sizeof(icurgroup));
+	memset(igroup, 0, sizeof(igroup));
+	memset(inick, 0, sizeof(inick));
+	memset(ihostmask, 0, sizeof(ihostmask));
+	off = 0;
+}
+
+void
+icb_recv(const char *buf, unsigned len, int fd, int server_fd)
 {
 	static unsigned char cmd[256];
-	static unsigned off = 0;
 
 	while (len > 0) {
 		if (off == 0) {
@@ -142,7 +157,7 @@ icb_recv(const char *buf, unsigned len, int fd)
 		}
 		/* len == 0 || (off - 1) == cmd[0] */
 		if ((off - 1) == cmd[0]) {
-			icb_cmd(cmd + 1, off - 1 /* <= 255 */, fd);
+			icb_cmd(cmd + 1, off - 1 /* <= 255 */, fd, server_fd);
 			off = 0;
 		}
 	}
@@ -175,7 +190,7 @@ icb_args(const char *data, unsigned char len, char args[255][255])
 }
 
 static void
-icb_cmd(const char *cmd, unsigned char len, int fd)
+icb_cmd(const char *cmd, unsigned char len, int fd, int server_fd)
 {
 	char args[255][255];
 	const char *a = args[1];
@@ -195,9 +210,18 @@ icb_cmd(const char *cmd, unsigned char len, int fd)
 		irc_send_code(fd, icb_hostid, irc_nick, "002",
 		    "Your host is %s running %s protocol %s",
 		    icb_hostid, icb_serverid, icb_protolevel);
+		/* some clients really want to see a MOTD */
+		irc_send_code(fd, icb_hostid, irc_nick, "375",
+		    "ICB server: %s", icb_serverid);
+		irc_send_code(fd, icb_hostid, irc_nick, "376",
+		    "End of MOTD");
 		icb_logged_in = 1;
 		break;
 	case 'b':	/* Open Message */
+		if (!in_irc_channel) {
+			irc_send_join(fd, irc_nick, irc_channel);
+			icb_send_names(server_fd, irc_channel);
+		}
 		irc_send_msg(fd, args[0], irc_channel, args[1]);
 		break;
 	case 'c':	/* Personal Message */
@@ -213,6 +237,7 @@ icb_cmd(const char *cmd, unsigned char len, int fd)
 			scan(&a, irc_channel + 1, sizeof(irc_channel) - 1,
 			    " ", " ");
 			irc_send_join(fd, irc_nick, irc_channel);
+			icb_send_names(server_fd, irc_channel);
 		} else if (!strcmp(args[0], "Arrive") ||
 		    !strcmp(args[0], "Sign-on")) {
 			char nick[256], host[256];
@@ -372,7 +397,7 @@ icb_iwl(int fd, const char *flags, const char *nick, long idle,
 		    icb_hostid, irc_nick, nick);
 		sync_write(fd, s, strlen(s));
 	} else if (imode == imode_names && !strcmp(icurgroup, igroup)) {
-		snprintf(s, sizeof(s), ":%s 353 %s @ %s :%s%s\r\n",
+		snprintf(s, sizeof(s), ":%s 353 %s @ %s :%s%s \r\n",
 		    icb_hostid, irc_nick, icurgroup, chanop ? "@" : "", nick);
 		sync_write(fd, s, strlen(s));
 		snprintf(s, sizeof(s), ":%s 352 %s %s %s %s %s %s H :5 %s\r\n",
@@ -690,3 +715,15 @@ icb_send_raw(int fd, const char *data)
 	cmd[0] = off - 1;
 	sync_write(fd, cmd, off);
 }
+
+void
+icb_send_noop(int fd)
+{
+	char cmd[256];
+	unsigned off = 1;
+
+	cmd[off++] = 'n';
+	cmd[off++] = 0;
+	cmd[0] = off - 1;
+	sync_write(fd, cmd, off);
+}
