@@ -1,4 +1,4 @@
-/*	$Id: icbirc.c,v 1.12 2004/04/15 10:20:35 dhartmei Exp $ */
+/*	$Id: icbirc.c,v 1.3 2016/04/25 08:17:01 dhartmei Exp $ */
 
 /*
  * Copyright (c) 2003-2004 Daniel Hartmeier
@@ -30,7 +30,7 @@
  *
  */
 
-static const char rcsid[] = "$Id: icbirc.c,v 1.12 2004/04/15 10:20:35 dhartmei Exp $";
+static const char rcsid[] = "$Id: icbirc.c,v 1.3 2016/04/25 08:17:01 dhartmei Exp $";
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -157,14 +157,19 @@ main(int argc, char *argv[])
 		goto error;
         }
 
-	printf("ready for incoming connection\n");
-
 	if (!debug && daemon(0, 0)) {
 		perror("daemon");
 		goto error;
 	}
 	signal(SIGPIPE, SIG_IGN);
 
+#ifdef __OpenBSD__
+	if (pledge("stdio inet dns", NULL) == -1) {
+		perror("pledge");
+		goto error;
+	}
+#endif /* __OpenBSD__ */
+
 	/* handle incoming client connections */
 	while (1) {
 		fd_set readfds;
@@ -230,7 +235,7 @@ handle_client(int client_fd)
 
 	printf("connecting to server %s:%u\n",
 	    inet_ntoa(sa_connect.sin_addr), ntohs(sa_connect.sin_port));
-	irc_send_notice(client_fd, "Connecting to server %s:%u",
+	irc_send_notice(client_fd, "*** Connecting to server %s:%u",
 	    inet_ntoa(sa_connect.sin_addr), ntohs(sa_connect.sin_port));
 	if ((server_fd = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
 		perror("socket");
@@ -239,7 +244,7 @@ handle_client(int client_fd)
 	if (connect(server_fd, (struct sockaddr *)&sa_connect,
 	    sizeof(sa_connect))) {
 		perror("connect");
-		irc_send_notice(client_fd, "Error: connect: %s",
+		irc_send_notice(client_fd, "*** Error: connect: %s",
 		    strerror(errno));
 		close(server_fd);
 		goto done;
@@ -256,8 +261,9 @@ handle_client(int client_fd)
 	else
 		max_fd = server_fd;
 
-	irc_send_notice(client_fd, "Connected");
+	irc_send_notice(client_fd, "*** Connected");
 	terminate_client = 0;
+	icb_init();
 	while (!terminate_client) {
 		fd_set readfds;
 		struct timeval tv;
@@ -291,10 +297,10 @@ handle_client(int client_fd)
 				if (len == 0) {
 					printf("connection closed by server\n");
 					irc_send_notice(client_fd,
-					    "Connection closed by server");
+					    "*** Connection closed by server");
 					break;
 				}
-				icb_recv(buf, len, client_fd);
+				icb_recv(buf, len, client_fd, server_fd);
 				bytes_in += len;
 			}
 			if (FD_ISSET(client_fd, &readfds)) {
@@ -318,10 +324,10 @@ handle_client(int client_fd)
 done:
 	if (server_fd >= 0)
 		close(server_fd);
-	printf("(%u seconds, %lu:%lu bytes)\n",
-	    time(NULL) - t, bytes_out, bytes_in);
+	printf("(%lu seconds, %lu:%lu bytes)\n",
+	    (unsigned long)(time(NULL) - t), bytes_out, bytes_in);
 	if (terminate_client)
-		irc_send_notice(client_fd, "Closing connection "
+		irc_send_notice(client_fd, "*** Closing connection "
 		    "(%u seconds, %lu:%lu bytes)",
 		    time(NULL) - t, bytes_out, bytes_in);
 }
