@@ -1,4 +1,4 @@
-/*	$Id: irc.c,v 1.12 2004/04/15 10:20:35 dhartmei Exp $ */
+/*	$Id: irc.c,v 1.2 2015/08/20 17:29:16 dhartmei Exp $ */
 
 /*
  * Copyright (c) 2003-2004 Daniel Hartmeier
@@ -30,7 +30,7 @@
  *
  */
 
-static const char rcsid[] = "$Id: irc.c,v 1.12 2004/04/15 10:20:35 dhartmei Exp $";
+static const char rcsid[] = "$Id: irc.c,v 1.2 2015/08/20 17:29:16 dhartmei Exp $";
 
 #include <stdarg.h>
 #include <stdio.h>
@@ -52,6 +52,7 @@ char irc_pass[256];
 char irc_ident[256];
 char irc_nick[256];
 char irc_channel[256];
+int in_irc_channel;
 
 /*
  * irc_recv() receives read(2) chunks and assembles complete lines, which are
@@ -119,6 +120,8 @@ irc_cmd(const char *cmd, int client_fd, int server_fd)
 			cmd++;
 		scan(&cmd, group, sizeof(group), " ", " ");
 		icb_send_group(server_fd, group);
+	} else if (!strncasecmp(cmd, "PART ", 5)) {
+		in_irc_channel = 0;
 	} else if (!strncasecmp(cmd, "PRIVMSG ", 8) ||
 	    !strncasecmp(cmd, "NOTICE ", 7)) {
 		char dst[128];
@@ -194,6 +197,7 @@ irc_cmd(const char *cmd, int client_fd, int server_fd)
 		}
 		icb_send_boot(server_fd, nick);
 	} else if (!strncasecmp(cmd, "PING ", 5)) {
+		icb_send_noop(server_fd);
 		cmd += 5;
 		irc_send_pong(client_fd, cmd);
 	} else if (!strncasecmp(cmd, "RAWICB ", 7)) {
@@ -249,6 +253,7 @@ irc_send_join(int fd, const char *src, const char *dst)
 
 	snprintf(cmd, sizeof(cmd), ":%s JOIN :%s\r\n", src, dst);
 	sync_write(fd, cmd, strlen(cmd));
+	in_irc_channel = 1;
 }
 
 void
